@@ -161,7 +161,7 @@ void
 usage()
 {
 	(void)fprintf(stderr,
-"usage: tset [-IQrs] [-] [-e ch] [-i ch] [-k ch] [-m mapping] [terminal]\n");
+"usage: tset [-IQrs] [-t] [-e ch] [-i ch] [-k ch] [-m mapping] [terminal]\n");
 	exit(1);
 }
 
